QUOTECAST_TIMEOUT = 15
TRADING_TIMEOUT = 1800  # [s] This value is used in the timeout documentation, see: https://github.com/Chavithra/degiro-connector#38-is-there-a-timeout-. Whenever this constant is changed, please update the docu
