# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: degiro_connector/quotecast/models/quotecast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1degiro_connector/quotecast/models/quotecast.proto\x12\x1a\x64\x65giro_connector.quotecast\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"v\n\x08Metadata\x12\x35\n\x11response_datetime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x10request_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xbe\x03\n\tQuotecast\x12\x11\n\tjson_data\x18\x01 \x01(\t\x12\x36\n\x08metadata\x18\x02 \x01(\x0b\x32$.degiro_connector.quotecast.Metadata\x1a\xe5\x02\n\x07Request\x12W\n\rsubscriptions\x18\x01 \x03(\x0b\x32@.degiro_connector.quotecast.Quotecast.Request.SubscriptionsEntry\x12[\n\x0funsubscriptions\x18\x02 \x03(\x0b\x32\x42.degiro_connector.quotecast.Quotecast.Request.UnsubscriptionsEntry\x1aP\n\x12SubscriptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\x1aR\n\x14UnsubscriptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\"\xfd\x02\n\x06Ticker\x12\x36\n\x08metadata\x18\x01 \x01(\x0b\x32$.degiro_connector.quotecast.Metadata\x12\x42\n\x08products\x18\x02 \x03(\x0b\x32\x30.degiro_connector.quotecast.Ticker.ProductsEntry\x12\x14\n\x0cproduct_list\x18\x03 \x03(\t\x1a\x83\x01\n\x07Metrics\x12H\n\x07metrics\x18\x01 \x03(\x0b\x32\x37.degiro_connector.quotecast.Ticker.Metrics.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a[\n\rProductsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.degiro_connector.quotecast.Ticker.Metrics:\x02\x38\x01\"\x85\x06\n\x05\x43hart\x12\x11\n\trequestid\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x12\n\nresolution\x18\x04 \x01(\t\x12\x37\n\x06series\x18\x05 \x03(\x0b\x32\'.degiro_connector.quotecast.Chart.Serie\x1a\xc1\x02\n\x07Request\x12\x11\n\trequestid\x18\x01 \x01(\t\x12>\n\nresolution\x18\x02 \x01(\x0e\x32*.degiro_connector.quotecast.Chart.Interval\x12\x0f\n\x07\x63ulture\x18\x03 \x01(\t\x12:\n\x06period\x18\x04 \x01(\x0e\x32*.degiro_connector.quotecast.Chart.Interval\x12\x0e\n\x06series\x18\x05 \x03(\t\x12\n\n\x02tz\x18\x06 \x01(\t\x12I\n\x08override\x18\x07 \x03(\x0b\x32\x37.degiro_connector.quotecast.Chart.Request.OverrideEntry\x1a/\n\rOverrideEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1ak\n\x05Serie\x12\r\n\x05times\x18\x01 \x01(\t\x12\x0f\n\x07\x65xpires\x18\x02 \x01(\t\x12(\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\"\xce\x01\n\x08Interval\x12\x08\n\x04PT1S\x10\x00\x12\t\n\x05PT15S\x10\x01\x12\t\n\x05PT30S\x10\x02\x12\x08\n\x04PT1M\x10\x03\x12\x08\n\x04PT5M\x10\x04\x12\t\n\x05PT15M\x10\x05\x12\t\n\x05PT30M\x10\x06\x12\t\n\x05PT60M\x10\x07\x12\x08\n\x04PT1H\x10\x08\x12\x07\n\x03P1D\x10\t\x12\x07\n\x03P1W\x10\n\x12\x07\n\x03P1M\x10\x0b\x12\x07\n\x03P3M\x10\x0c\x12\x07\n\x03P6M\x10\r\x12\x07\n\x03P1Y\x10\x0e\x12\x07\n\x03P3Y\x10\x0f\x12\x07\n\x03P5Y\x10\x10\x12\x08\n\x04P10Y\x10\x11\x12\x08\n\x04P50Y\x10\x12\x12\x07\n\x03YTD\x10\x13\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'degiro_connector.quotecast.models.quotecast_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY._options = None
  _QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY._serialized_options = b'8\001'
  _QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY._options = None
  _QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY._serialized_options = b'8\001'
  _TICKER_METRICS_METRICSENTRY._options = None
  _TICKER_METRICS_METRICSENTRY._serialized_options = b'8\001'
  _TICKER_PRODUCTSENTRY._options = None
  _TICKER_PRODUCTSENTRY._serialized_options = b'8\001'
  _CHART_REQUEST_OVERRIDEENTRY._options = None
  _CHART_REQUEST_OVERRIDEENTRY._serialized_options = b'8\001'
  _METADATA._serialized_start=176
  _METADATA._serialized_end=294
  _QUOTECAST._serialized_start=297
  _QUOTECAST._serialized_end=743
  _QUOTECAST_REQUEST._serialized_start=386
  _QUOTECAST_REQUEST._serialized_end=743
  _QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY._serialized_start=579
  _QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY._serialized_end=659
  _QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY._serialized_start=661
  _QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY._serialized_end=743
  _TICKER._serialized_start=746
  _TICKER._serialized_end=1127
  _TICKER_METRICS._serialized_start=903
  _TICKER_METRICS._serialized_end=1034
  _TICKER_METRICS_METRICSENTRY._serialized_start=988
  _TICKER_METRICS_METRICSENTRY._serialized_end=1034
  _TICKER_PRODUCTSENTRY._serialized_start=1036
  _TICKER_PRODUCTSENTRY._serialized_end=1127
  _CHART._serialized_start=1130
  _CHART._serialized_end=1903
  _CHART_REQUEST._serialized_start=1264
  _CHART_REQUEST._serialized_end=1585
  _CHART_REQUEST_OVERRIDEENTRY._serialized_start=1538
  _CHART_REQUEST_OVERRIDEENTRY._serialized_end=1585
  _CHART_SERIE._serialized_start=1587
  _CHART_SERIE._serialized_end=1694
  _CHART_INTERVAL._serialized_start=1697
  _CHART_INTERVAL._serialized_end=1903
# @@protoc_insertion_point(module_scope)
