# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: degiro_connector/quotecast/models/quotecast_relay.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from degiro_connector.quotecast.models import quotecast_pb2 as degiro__connector_dot_quotecast_dot_models_dot_quotecast__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7degiro_connector/quotecast/models/quotecast_relay.proto\x12 degiro_connector.quotecast_relay\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x31\x64\x65giro_connector/quotecast/models/quotecast.proto\"5\n\tSetConfig\x12\x12\n\nuser_token\x18\x01 \x01(\x05\x12\x14\n\x0c\x61uto_connect\x18\x02 \x01(\x08\x32\xb2\x03\n\x0eQuotecastRelay\x12W\n\nset_config\x12+.degiro_connector.quotecast_relay.SetConfig\x1a\x1a.google.protobuf.BoolValue\"\x00\x12\x41\n\x07\x63onnect\x12\x16.google.protobuf.Empty\x1a\x1c.google.protobuf.StringValue\"\x00\x12M\n\nfetch_data\x12\x16.google.protobuf.Empty\x1a%.degiro_connector.quotecast.Quotecast\"\x00\x12[\n\tget_chart\x12).degiro_connector.quotecast.Chart.Request\x1a!.degiro_connector.quotecast.Chart\"\x00\x12X\n\tsubscribe\x12-.degiro_connector.quotecast.Quotecast.Request\x1a\x1a.google.protobuf.BoolValue\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'degiro_connector.quotecast.models.quotecast_relay_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SETCONFIG._serialized_start=205
  _SETCONFIG._serialized_end=258
  _QUOTECASTRELAY._serialized_start=261
  _QUOTECASTRELAY._serialized_end=695
# @@protoc_insertion_point(module_scope)
